@@ -6,13 +6,20 @@ from . import (
     grids,
     io,
     plot,
+    oceans,
+    pygplates
 )
+
 from .data import DataCollection
 from .download import DataServer
-from .grids import Raster, TimeRaster
+from .grids import (
+    Raster,
+    # TimeRaster,
+)
 from .io import get_geometries, get_valid_geometries
 from .plot import PlotTopologies
-from .reconstruction import PlateReconstruction, Points
+from .reconstruction import PlateReconstruction, Points, DefaultCollision, ContinentCollision, ReconstructByTopologies
 from .tools import EARTH_RADIUS
+from .oceans import SeafloorGrid
 
-__pdoc__ = {"data" : False}
\ No newline at end of file
+__pdoc__ = {"data" : False}
