@@ -15,6 +15,8 @@ from pooch import HTTPDownloader as _HTTPDownloader
 from pooch import Unzip as _Unzip
 from pooch import Decompress as _Decompress
 from matplotlib import image as _image
+from .pygplates import RotationModel as _RotationModel
+from .pygplates import FeatureCollection as _FeatureCollection
 from gplately.data import DataCollection
 import gplately as _gplately
 import pygplates as _pygplates
@@ -138,7 +140,7 @@ def _first_time_download_from_web(url):
         return(fnames, etag, textfilename)
     
     
-def download_from_web(url, download_changes=True):
+def download_from_web(url, verbose=True, download_changes=True):
     """Download a file from a `url` into the `gplately` cache.
     
     Notes
@@ -181,6 +183,9 @@ def download_from_web(url, download_changes=True):
     url : str
         The full URL used to download a file from a public web server
         like webDAV.
+    verbose : bool
+        Choose whether to print user alerts regarding file availability,
+        data server/internet connection status etc. 
     download_changes : bool, default=True
         Permit the re-downloading/update of the file from `url` if 
         it has been updated on the web server since the last download.
@@ -209,7 +214,8 @@ def download_from_web(url, download_changes=True):
         # download files from the URL and create a textfile for this URL's E-Tag
         if _test_internet_connection(url):
             fnames, etag, textfilename = _first_time_download_from_web(url)
-            print("Requested files downloaded to the GPlately cache folder!")
+            if verbose:
+                print("Requested files downloaded to the GPlately cache folder!")
             return(fnames)
     
         # ... if a connection to the web server cannot be established
@@ -239,7 +245,8 @@ def download_from_web(url, download_changes=True):
 
                 # If the e-tag textfile exists for the local files,
                 else: 
-                    print("Checking whether the requested files need to be updated...")
+                    if verbose:
+                        print("Checking whether the requested files need to be updated...")
 
                     # Determine the local file's URL e-tag from the textfile
                     with open(local_etag_txtfile) as f:
@@ -251,7 +258,8 @@ def download_from_web(url, download_changes=True):
                     # If the local and remote e-tags are unequal, the web-server URL 
                     # contains an updated version of the cached files.
                     if str(remote_etag) != str(local_etag):
-                        print("Yes - updating requested files...")
+                        if verbose:
+                            print("Yes - updating requested files...")
                         
                         # Update the e-tag textfile with this newly-identified URL e-tag
                         _save_url_etag_to_txt(remote_etag, remote_etag_textfile)
@@ -266,13 +274,15 @@ def download_from_web(url, download_changes=True):
                             # determine_processor gives the file its processed filename
                             processed_file = str(full_path)+_determine_processor(url)[1]
 
-                        print("Requested files downloaded to the GPlately cache folder!")
+                        if verbose:
+                            print("Requested files downloaded to the GPlately cache folder!")
                         return(_extract_processed_files(processed_file))
 
                     # If the e-tags are equal, the local and remote files are the same.
                     # Just return the file(s) as-is.
                     else:
-                        print("Requested files are up-to-date!")
+                        if verbose:
+                            print("Requested files are up-to-date!")
                         return(_extract_processed_files(
                             str(full_path)+_determine_processor(url)[1]))
             
@@ -726,11 +736,20 @@ class DataServer(object):
         Reconstruction of Western North America and the Eastern Pacific Basin. Geochemistry, Geophysics, 
         Geosystems, 21, e2020GC009117. DOI: https://doi.org/10.1029/2020GC009117
 
-    """
-    def __init__(self, file_collection):
+        Parameters
+        ----------
+        file_collection : str
+            name of file collection to use
 
-        self.file_collection = file_collection
+        verbose : bool, default True
+            Toggle print messages regarding server/internet connection status, file availability etc.
+
+    """
+    def __init__(self, file_collection, verbose=True):
+
+        self.file_collection = file_collection.capitalize()
         self.data_collection = DataCollection(self.file_collection)
+        self.verbose = verbose
 
 
     def get_plate_reconstruction_files(self):
@@ -774,11 +793,13 @@ class DataServer(object):
 
         """
 
+        verbose = self.verbose
+
         rotation_filenames = []
         rotation_model = []
         topology_filenames = []
-        topology_features = _pygplates.FeatureCollection()
-        static_polygons= _pygplates.FeatureCollection()
+        topology_features = _FeatureCollection()
+        static_polygons= _FeatureCollection()
         static_polygon_filenames = []
 
         # Locate all plate reconstruction files from GPlately's DataCollection
@@ -793,7 +814,7 @@ class DataServer(object):
                 found_collection = True
                 if len(url) == 1:
                     fnames = _collection_sorter(
-                        download_from_web(url[0]), self.file_collection
+                        download_from_web(url[0], verbose), self.file_collection
                     )
                     rotation_filenames = _collect_file_extension(
                         _str_in_folder(
@@ -805,7 +826,7 @@ class DataServer(object):
                         [".rot"]
                     )
                     #print(rotation_filenames)
-                    rotation_model = _pygplates.RotationModel(rotation_filenames)
+                    rotation_model = _RotationModel(rotation_filenames)
 
                     topology_filenames = _collect_file_extension(
                         _str_in_folder(
@@ -819,7 +840,7 @@ class DataServer(object):
                     )
                     #print(topology_filenames)
                     for file in topology_filenames:
-                        topology_features.add(_pygplates.FeatureCollection(file))
+                        topology_features.add(_FeatureCollection(file))
 
                     static_polygon_filenames = _check_gpml_or_shp(
                         _str_in_folder(
@@ -832,31 +853,23 @@ class DataServer(object):
                     )
                     #print(static_polygon_filenames)
                     for stat in static_polygon_filenames:
-                        static_polygons.add(_pygplates.FeatureCollection(stat))
+                        static_polygons.add(_FeatureCollection(stat))
 
                 else:
                     for file in url[0]:
-                        rotation_filenames.append(
-                            _collect_file_extension(
-                                download_from_web(file), [".rot"])
-                        )
-                        rotation_model = _pygplates.RotationModel(rotation_filenames)
+                        rotation_filenames.append(_collect_file_extension(download_from_web(file, verbose), [".rot"]))
+                        rotation_model = _RotationModel(rotation_filenames)
 
                     for file in url[1]:
-                        topology_filenames.append(
-                            _collect_file_extension(
-                                download_from_web(file), [".gpml"])
-                        )
+                        topology_filenames.append(_collect_file_extension(download_from_web(file, verbose), [".gpml"]))
                         for file in topology_filenames:
-                            topology_features.add(
-                                _pygplates.FeatureCollection(file)
-                            )
+                            topology_features.add(_FeatureCollection(file))
 
                     for file in url[2]:
                         static_polygon_filenames.append(
                             _check_gpml_or_shp(
                                 _str_in_folder(
-                                    _str_in_filename(download_from_web(url[0]), 
+                                    _str_in_filename(download_from_web(url[0], verbose), 
                                         strings_to_include=DataCollection.static_polygon_strings_to_include(self)
                                     ),    
                                         strings_to_ignore=DataCollection.static_polygon_strings_to_ignore(self)
@@ -864,7 +877,7 @@ class DataServer(object):
                             )   
                         )
                         for stat in static_polygon_filenames:
-                            static_polygons.add(_pygplates.FeatureCollection(stat))
+                            static_polygons.add(_FeatureCollection(stat))
                 break
 
         if found_collection is False:
@@ -880,6 +893,9 @@ class DataServer(object):
             print("No static polygons in {}.".format(self.file_collection))
             static_polygons = []
 
+        # add identifier for setting up DownloadServer independently
+        rotation_model.reconstruction_identifier = self.file_collection
+
         return rotation_model, topology_features, static_polygons
 
 
@@ -888,6 +904,11 @@ class DataServer(object):
         Shapely geometries from the requested plate model. These are needed to call the `PlotTopologies`
         object and visualise topological plates through time.
 
+        Parameters
+        ----------
+        verbose : bool, default True
+            Toggle print messages regarding server/internet connection status, file availability etc.
+
         Returns
         -------
         coastlines : instance of <pygplates.FeatureCollection>
@@ -931,6 +952,8 @@ class DataServer(object):
                 No continent-ocean boundaries in Matthews2016.
         """
 
+        verbose = self.verbose
+
         # Locate all topology geometries from GPlately's DataCollection
         database = DataCollection.topology_geometries(self)
 
@@ -951,7 +974,7 @@ class DataServer(object):
                         break
                     else:
                         fnames = _collection_sorter(
-                            download_from_web(url[0]), self.file_collection
+                            download_from_web(url[0], verbose), self.file_collection
                         )
                         coastlines = _check_gpml_or_shp(
                             _str_in_folder(
@@ -987,7 +1010,7 @@ class DataServer(object):
                     for file in url[0]:
                         if url[0] is not None:
                             coastlines.append(_str_in_filename(
-                                download_from_web(file), 
+                                download_from_web(file, verbose), 
                                 strings_to_include=["coastline"])
                             )
                             coastlines = _check_gpml_or_shp(coastlines)
@@ -997,7 +1020,7 @@ class DataServer(object):
                     for file in url[1]:
                         if url[1] is not None:
                             continents.append(_str_in_filename(
-                                download_from_web(file), 
+                                download_from_web(file, verbose), 
                                 strings_to_include=["continent"])
                             )
                             continents = _check_gpml_or_shp(continents)
@@ -1007,7 +1030,7 @@ class DataServer(object):
                     for file in url[2]:
                         if url[2] is not None:
                             COBs.append(_str_in_filename(
-                                download_from_web(file), 
+                                download_from_web(file, verbose), 
                                 strings_to_include=["cob"])
                             )
                             COBs = _check_gpml_or_shp(COBs)
@@ -1023,27 +1046,27 @@ class DataServer(object):
             coastlines_featurecollection = []
         else:
             #print(coastlines)
-            coastlines_featurecollection = _pygplates.FeatureCollection()
+            coastlines_featurecollection = _FeatureCollection()
             for coastline in coastlines:
-                coastlines_featurecollection.add(_pygplates.FeatureCollection(coastline))
+                coastlines_featurecollection.add(_FeatureCollection(coastline))
         
         if not continents:
             print("No continents in {}.".format(self.file_collection))
             continents_featurecollection = []
         else:
             #print(continents)
-            continents_featurecollection = _pygplates.FeatureCollection()
+            continents_featurecollection = _FeatureCollection()
             for continent in continents:
-                continents_featurecollection.add(_pygplates.FeatureCollection(continent))
+                continents_featurecollection.add(_FeatureCollection(continent))
         
         if not COBs:
             print("No continent-ocean boundaries in {}.".format(self.file_collection))
             COBs_featurecollection = []
         else:
             #print(COBs)
-            COBs_featurecollection = _pygplates.FeatureCollection()
+            COBs_featurecollection = _FeatureCollection()
             for COB in COBs:
-                COBs_featurecollection.add(_pygplates.FeatureCollection(COB))
+                COBs_featurecollection.add(_FeatureCollection(COB))
         
         geometries = coastlines_featurecollection, continents_featurecollection, COBs_featurecollection
         return geometries
@@ -1117,8 +1140,12 @@ class DataServer(object):
         """
         age_grids = []
         age_grid_links = DataCollection.netcdf4_age_grids(self, time)
+
+        if not age_grid_links:
+            raise ValueError("{} age grids are not on GPlately's DataServer.".format(self.file_collection))
+
         for link in age_grid_links:
-            age_grid_file = download_from_web(link)
+            age_grid_file = download_from_web(link, self.verbose)
             age_grid = _gplately.grids.read_netcdf_grid(age_grid_file)
             age_grids.append(age_grid)
 
@@ -1191,8 +1218,12 @@ class DataServer(object):
         """
         spreading_rate_grids = []
         spreading_rate_grid_links = DataCollection.netcdf4_spreading_rate_grids(self, time)
+
+        if not spreading_rate_grid_links:
+            raise ValueError("{} spreading rate grids are not on GPlately's DataServer.".format(self.file_collection))
+
         for link in spreading_rate_grid_links:
-            spreading_rate_grid_file = download_from_web(link)
+            spreading_rate_grid_file = download_from_web(link, self.verbose)
             spreading_rate_grid = _gplately.grids.read_netcdf_grid(spreading_rate_grid_file)
             spreading_rate_grids.append(spreading_rate_grid)
 
@@ -1226,9 +1257,9 @@ class DataServer(object):
 
         Returns
         -------
-        raster_filenames : ndarray
-            An ndarray of the cached raster. This can be plotted using `matplotlib.pyplot.imshow` on
-            a `cartopy.mpl.GeoAxis` GeoAxesSubplot (see example below).
+        raster_filenames : ndarray or MaskedArray
+            An ndarray or MaskedArray of the cached raster. This can be plotted using 
+            `matplotlib.pyplot.imshow` on a `cartopy.mpl.GeoAxis` GeoAxesSubplot (see example below).
 
         Raises
         ------
@@ -1263,6 +1294,8 @@ class DataServer(object):
         #filetype = "."+"_".split(raster_id_string)[-1]
 
         archive_formats = tuple([".gz", ".xz", ".bz2"])
+        grid_extensions = tuple([".grd", ".nc"])
+
         # Set to true if we find the given collection in database
         found_collection = False
         raster_filenames = []
@@ -1273,14 +1306,20 @@ class DataServer(object):
             #raster_name = collection.split("_")[0]
             #raster_type = "."+collection.split("_")[-1]
             if (raster_id_string.lower() == collection.lower()):
-                raster_filenames = download_from_web(zip_url[0])
+                raster_filenames = download_from_web(zip_url[0], self.verbose)
                 found_collection = True
                 break
 
         if found_collection is False:
             raise ValueError("{} not in collection database.".format(raster_id_string))
         else:
-            raster_matrix = image.imread(raster_filenames)
+            # If the downloaded raster is a grid, process it with the gplately.Raster object
+            if any(grid_extension in raster_filenames for grid_extension in grid_extensions):
+                raster_matrix = _gplately.grids.Raster(data=raster_filenames).data
+
+            # Otherwise, the raster is an image; use imread to process
+            else:
+                raster_matrix = image.imread(raster_filenames)
         return raster_matrix
 
 
@@ -1388,20 +1427,23 @@ class DataServer(object):
                 found_collection = True
                 feature_data_filenames = _collection_sorter(
                     _collect_file_extension(
-                    download_from_web(zip_url[0]), [".gpml", ".gpmlz"]
+                    download_from_web(zip_url[0], self.verbose), [".gpml", ".gpmlz"]
                     ),
                     collection
                 )
 
                 break
 
-        feat_data = _pygplates.FeatureCollection()
+        if found_collection is False:
+            raise ValueError("{} are not in GPlately's DataServer.".format(feature_data_id_string))
+
+        feat_data = _FeatureCollection()
         if len(feature_data_filenames) == 1:
-                feat_data.add(_pygplates.FeatureCollection(feature_data_filenames[0]))
+                feat_data.add(_FeatureCollection(feature_data_filenames[0]))
                 return feat_data
         else:    
             feat_data=[]
             for file in feature_data_filenames:
-                feat_data.append(_pygplates.FeatureCollection(file))
+                feat_data.append(_FeatureCollection(file))
             return feat_data
     
\ No newline at end of file
