@@ -35,4 +35,10 @@ def test_point_reconstruction(time, gpts):
 @pytest.mark.parametrize("time", reconstruction_times)
 def test_plate_velocity(time, gpts):
     plate_vel = gpts.plate_velocity(time, delta_time=1)
-    assert plate_vel, "Unable to calculate plate velocities of point data at {} Ma with Muller et al. (2019).".format(time)
\ No newline at end of file
+    assert plate_vel, "Unable to calculate plate velocities of point data at {} Ma with Muller et al. (2019).".format(time)
+
+
+def test_pickle_Points():
+    import pickle
+    gpts_dump = pickle.dumps(gpts)
+    gpts_load = pickle.loads(gpts_dump)
\ No newline at end of file
